==> ecip-codegen-0.4.19.tgz: package/src/api/vue/genScheme/gencodeSchemeApi.js <==
/**
 * @Author: huxiaolong
 * @File: gencode-scheme.js
 * @DATE: 2019-09-10
 * @TIME: 09:55
 */

import request from 'ecip-web/utils/request'

/* 获取生成方案列表 */
export const getSchemeData = (params, data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/data',
    method: 'post',
    params: params,
    data: data
  })
}

/* 根据生成方案Id获取生成方案 */
export const getSchemeById = (id) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/getById`,
    method: 'get',
    params: { id: id }
  })
}

/* 根据表单Id获取生成方案 */
export const getSchemeByTableId = (genTableId) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/genTable/${genTableId}`,
    method: 'get'
  })
}

/* 删除生成方案 */
export const deleteSchemeByIds = (ids) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/deleteByIds',
    method: 'delete',
    data: ids
  })
}

/* 编辑保存生成方案 */
export const updateScheme = (id, data) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/updateScheme/${id}`,
    method: 'put',
    data: data
  })
}

/* 保存生成方案 */
export const saveScheme = (data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/saveScheme',
    method: 'post',
    data: data
  })
}

/* 根据生成方案进行代码生成 */
export const schemeGencode = (isCover, data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/schemeCodegen',
    method: 'post',
    params: { isCover: isCover },
    data: data
  })
}

/* 根据表单页面进行代码生成 */
export const gencodeByScheme = (isCover, data) => {
  return request({
    url: 'api/v1/scheme',
    method: 'post',
    params: { isCover: isCover },
    data: data
  })
}

/* 根据表单页面进行代码生成下载 */
export const schemeCodegenDownload = (data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/downloadCode',
    method: 'post',
    data: data,
    responseType: 'blob'
  })
}

/* 根据生成方案预览代码生成(自定义) */
export const schemeCustomPreview = (params) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/schemeCodegenPreview',
    method: 'post',
    data: params
  })
}

/* 根据生成方案预览代码生成(非自定义) */
export const schemeExtraPreview = (params) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/preview',
    method: 'post',
    data: params
  })
}

export const findSchemesByGenTableId = (id) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/findByGenTableId/${id}`,
    method: 'get'
  })
}

==> ecip-codegen-0.4.21.tgz: package/src/api/vue/genScheme/gencodeSchemeApi.js <==
/**
 * @Author: huxiaolong
 * @File: gencode-scheme.js
 * @DATE: 2019-09-10
 * @TIME: 09:55
 */

import request from 'ecip-web/utils/request'

/* 获取生成方案列表 */
export const getSchemeData = (params, data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/data',
    method: 'post',
    params: params,
    data: data
  })
}

/* 根据生成方案Id获取生成方案 */
export const getSchemeById = (id) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/getById`,
    method: 'get',
    params: { id: id }
  })
}

/* 根据表单Id获取生成方案 */
export const getSchemeByTableId = (genTableId) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/genTable/${genTableId}`,
    method: 'get'
  })
}

/* 删除生成方案 */
export const deleteSchemeByIds = (ids) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/deleteByIds',
    method: 'delete',
    data: ids
  })
}

/* 编辑保存生成方案 */
export const updateScheme = (id, data) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/updateScheme/${id}`,
    method: 'put',
    data: data
  })
}

/* 保存生成方案 */
export const saveScheme = (data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/saveScheme',
    method: 'post',
    data: data
  })
}

/* 根据生成方案进行代码生成 */
export const schemeGencode = (isCover, data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/schemeCodegen',
    method: 'post',
    params: { isCover: isCover },
    data: data
  })
}

/* 根据表单页面进行代码生成 */
export const gencodeByScheme = (isCover, data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme',
    method: 'post',
    params: { isCover: isCover },
    data: data
  })
}

/* 根据表单页面进行代码生成下载 */
export const schemeCodegenDownload = (data) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/downloadCode',
    method: 'post',
    data: data,
    responseType: 'blob'
  })
}

/* 根据生成方案预览代码生成(自定义) */
export const schemeCustomPreview = (params) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/schemeCodegenPreview',
    method: 'post',
    data: params
  })
}

/* 根据生成方案预览代码生成(非自定义) */
export const schemeExtraPreview = (params) => {
  return request({
    url: 'api/v1/scheme/gencodeScheme/preview',
    method: 'post',
    data: params
  })
}

export const findSchemesByGenTableId = (id) => {
  return request({
    url: `api/v1/scheme/gencodeScheme/findByGenTableId/${id}`,
    method: 'get'
  })
}
